@@ -8,7 +8,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_001'; # VERSION
+our $VERSION = '0.040_002'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -17,7 +17,8 @@ with qw( Pinto::Role::Interface::Action
          Pinto::Role::Attribute::archives
          Pinto::Role::Attribute::stack
          Pinto::Role::Attribute::pin
-         Pinto::Role::Attribute::norecurse );
+         Pinto::Role::Attribute::norecurse
+         Pinto::Role::Attribute::dryrun );
 
 #------------------------------------------------------------------------------
 
@@ -35,7 +36,7 @@ Pinto::Role::Interface::Action::Add - Interface for Action::Add
 
 =head1 VERSION
 
-version 0.040_001
+version 0.040_002
 
 =head1 AUTHOR
 
